==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSimpleCellTessellator.java <==
// java wrapper for vtkSimpleCellTessellator object
//

package vtk;
import vtk.*;

public class vtkSimpleCellTessellator extends vtkGenericCellTessellator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetGenericCell_2();
  public vtkGenericAdaptorCell GetGenericCell() {
    long temp = GetGenericCell_2();

    if (temp == 0) return null;
    return (vtkGenericAdaptorCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void TessellateFace_3(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,int id2,vtkDoubleArray id3,vtkCellArray id4,vtkPointData id5);
  public void TessellateFace(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,int id2,vtkDoubleArray id3,vtkCellArray id4,vtkPointData id5)
    { TessellateFace_3(id0,id1,id2,id3,id4,id5); }

  private native void Tessellate_4(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4);
  public void Tessellate(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4)
    { Tessellate_4(id0,id1,id2,id3,id4); }

  private native void Triangulate_5(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4);
  public void Triangulate(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4)
    { Triangulate_5(id0,id1,id2,id3,id4); }

  private native void Reset_6();
  public void Reset()
    { Reset_6(); }

  private native void Initialize_7(vtkGenericDataSet id0);
  public void Initialize(vtkGenericDataSet id0)
    { Initialize_7(id0); }

  private native int GetFixedSubdivisions_8();
  public int GetFixedSubdivisions()
    { return GetFixedSubdivisions_8(); }

  private native int GetMaxSubdivisionLevel_9();
  public int GetMaxSubdivisionLevel()
    { return GetMaxSubdivisionLevel_9(); }

  private native int GetMaxAdaptiveSubdivisions_10();
  public int GetMaxAdaptiveSubdivisions()
    { return GetMaxAdaptiveSubdivisions_10(); }

  private native void SetFixedSubdivisions_11(int id0);
  public void SetFixedSubdivisions(int id0)
    { SetFixedSubdivisions_11(id0); }

  private native void SetMaxSubdivisionLevel_12(int id0);
  public void SetMaxSubdivisionLevel(int id0)
    { SetMaxSubdivisionLevel_12(id0); }

  private native void SetSubdivisionLevels_13(int id0,int id1);
  public void SetSubdivisionLevels(int id0,int id1)
    { SetSubdivisionLevels_13(id0,id1); }

  public vtkSimpleCellTessellator() { super(); }

  public vtkSimpleCellTessellator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-15-aarch64.pkg.tar.xz: vtk/vtkSimpleCellTessellator.java <==
// java wrapper for vtkSimpleCellTessellator object
//

package vtk;
import vtk.*;

public class vtkSimpleCellTessellator extends vtkGenericCellTessellator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetGenericCell_2();
  public vtkGenericAdaptorCell GetGenericCell() {
    long temp = GetGenericCell_2();

    if (temp == 0) return null;
    return (vtkGenericAdaptorCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void TessellateFace_3(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,int id2,vtkDoubleArray id3,vtkCellArray id4,vtkPointData id5);
  public void TessellateFace(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,int id2,vtkDoubleArray id3,vtkCellArray id4,vtkPointData id5)
    { TessellateFace_3(id0,id1,id2,id3,id4,id5); }

  private native void Tessellate_4(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4);
  public void Tessellate(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4)
    { Tessellate_4(id0,id1,id2,id3,id4); }

  private native void Triangulate_5(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4);
  public void Triangulate(vtkGenericAdaptorCell id0,vtkGenericAttributeCollection id1,vtkDoubleArray id2,vtkCellArray id3,vtkPointData id4)
    { Triangulate_5(id0,id1,id2,id3,id4); }

  private native void Reset_6();
  public void Reset()
    { Reset_6(); }

  private native void Initialize_7(vtkGenericDataSet id0);
  public void Initialize(vtkGenericDataSet id0)
    { Initialize_7(id0); }

  private native int GetFixedSubdivisions_8();
  public int GetFixedSubdivisions()
    { return GetFixedSubdivisions_8(); }

  private native int GetMaxSubdivisionLevel_9();
  public int GetMaxSubdivisionLevel()
    { return GetMaxSubdivisionLevel_9(); }

  private native int GetMaxAdaptiveSubdivisions_10();
  public int GetMaxAdaptiveSubdivisions()
    { return GetMaxAdaptiveSubdivisions_10(); }

  private native void SetFixedSubdivisions_11(int id0);
  public void SetFixedSubdivisions(int id0)
    { SetFixedSubdivisions_11(id0); }

  private native void SetMaxSubdivisionLevel_12(int id0);
  public void SetMaxSubdivisionLevel(int id0)
    { SetMaxSubdivisionLevel_12(id0); }

  private native void SetSubdivisionLevels_13(int id0,int id1);
  public void SetSubdivisionLevels(int id0,int id1)
    { SetSubdivisionLevels_13(id0,id1); }

  public vtkSimpleCellTessellator() { super(); }

  public vtkSimpleCellTessellator(long id) { super(id); }
  public native long   VTKInit();

}
